# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Private Classes

* `application::common`: Boring implementation details

### Defined types

* [`application`](#application): Declare an application to orchestrate deployments
* [`application::kind`](#application--kind): Declare a set of hooks for application deployment

### Tasks

* [`activate`](#activate): Activate a deployment of an application
* [`deploy`](#deploy): Create a new deployment for an application
* [`list`](#list): List applications and deployments
* [`prune`](#prune): Prune old deployments of an application
* [`remove`](#remove): Remove a deployment from an application

## Defined types

### <a name="application"></a>`application`

Declare an application to orchestrate deployments

#### Parameters

The following parameters are available in the `application` defined type:

* [`application`](#-application--application)
* [`environment`](#-application--environment)
* [`path`](#-application--path)
* [`deploy_user`](#-application--deploy_user)
* [`deploy_group`](#-application--deploy_group)
* [`user_mapping`](#-application--user_mapping)
* [`group_mapping`](#-application--group_mapping)
* [`kind`](#-application--kind)
* [`retention_min`](#-application--retention_min)
* [`retention_max`](#-application--retention_max)

##### <a name="-application--application"></a>`application`

Data type: `String[1]`

Name of the application to deploy

##### <a name="-application--environment"></a>`environment`

Data type: `String[1]`

Environment of the application to deploy

##### <a name="-application--path"></a>`path`

Data type: `Stdlib::Absolutepath`

Path of the application

##### <a name="-application--deploy_user"></a>`deploy_user`

Data type: `Optional[String[1]]`

User used to deploy the application

Default value: `undef`

##### <a name="-application--deploy_group"></a>`deploy_group`

Data type: `Optional[String[1]]`

Group used to deploy the application

Default value: `undef`

##### <a name="-application--user_mapping"></a>`user_mapping`

Data type: `Hash[String[1], String[1]]`

User mapping for managing deployment file permissions

Default value: `{}`

##### <a name="-application--group_mapping"></a>`group_mapping`

Data type: `Hash[String[1], String[1]]`

Group mapping for managing deployment file permissions

Default value: `$user_mapping`

##### <a name="-application--kind"></a>`kind`

Data type: `Optional[String[1]]`

Kind of the application to deploy

Default value: `undef`

##### <a name="-application--retention_min"></a>`retention_min`

Data type: `Integer[1]`

Minimum number of deployments to keep on disk when pruning

Default value: `5`

##### <a name="-application--retention_max"></a>`retention_max`

Data type: `Optional[Integer[1]]`

Maximum number of deployments to keep on disk after deploying a new deployment (enable auto-pruning)

Default value: `undef`

### <a name="application--kind"></a>`application::kind`

Hooks are run from the deployment directory as the user configured by `deploy_user` in the application.

The following hooks are available:

* before_deploy
* after_deploy
* before_activate
* after_activate

A `before_*` hook returning with a non-zero exit code aborts the operation.
The exit code of `after_*` hooks is ignored.

The following environment variables are set for each hook invocation:

* `APPLICATION_NAME` - The name of the application (e.g. "acme")
* `APPLICATION_PATH` - The path of the application (e.g. "/opt/acme")
* `ENVIRONMENT` - The name of the environment (e.g. "production")
* `DEPLOYMENT_NAME` - The name of the deployment (e.g. "d3")
* `DEPLOYMENT_PATH` - The path of the deployment (e.g. "/opt/acme/d3")
* `USER_MAPPING_*` - User mappings
* `GROUP_MAPPING_*` - Group mappings

Each hook can be set using the corresponding `*_content` or `*_source` parameter.

#### Parameters

The following parameters are available in the `application::kind` defined type:

* [`before_deploy_content`](#-application--kind--before_deploy_content)
* [`before_deploy_source`](#-application--kind--before_deploy_source)
* [`after_deploy_content`](#-application--kind--after_deploy_content)
* [`after_deploy_source`](#-application--kind--after_deploy_source)
* [`before_activate_content`](#-application--kind--before_activate_content)
* [`before_activate_source`](#-application--kind--before_activate_source)
* [`after_activate_content`](#-application--kind--after_activate_content)
* [`after_activate_source`](#-application--kind--after_activate_source)

##### <a name="-application--kind--before_deploy_content"></a>`before_deploy_content`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-application--kind--before_deploy_source"></a>`before_deploy_source`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-application--kind--after_deploy_content"></a>`after_deploy_content`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-application--kind--after_deploy_source"></a>`after_deploy_source`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-application--kind--before_activate_content"></a>`before_activate_content`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-application--kind--before_activate_source"></a>`before_activate_source`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-application--kind--after_activate_content"></a>`after_activate_content`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-application--kind--after_activate_source"></a>`after_activate_source`

Data type: `Optional[String[1]]`



Default value: `undef`

## Tasks

### <a name="activate"></a>`activate`

Activate a deployment of an application

**Supports noop?** false

#### Parameters

##### `application`

Data type: `String[1]`

The application to operate on

##### `environment`

Data type: `String[1]`

The environment to operate on

##### `deployment_name`

Data type: `String[1]`

The name of the deployment to activate

### <a name="deploy"></a>`deploy`

Create a new deployment for an application

**Supports noop?** false

#### Parameters

##### `application`

Data type: `String[1]`

The application to operate on

##### `environment`

Data type: `String[1]`

The environment to operate on

##### `url`

Data type: `String[1]`

The url of the artifact of the deployment

##### `deployment_name`

Data type: `Optional[String[1]]`

The name of the deployment to create

##### `headers`

Data type: `Optional[Hash[String[1], String[1]]]`

Extra HTTP headers

### <a name="list"></a>`list`

List applications and deployments

**Supports noop?** false

### <a name="prune"></a>`prune`

Prune old deployments of an application

**Supports noop?** false

#### Parameters

##### `application`

Data type: `String[1]`

The application to operate on

##### `environment`

Data type: `String[1]`

The environment to operate on

##### `keep`

Data type: `Integer[1]`

The number of MRU deployments to keep

### <a name="remove"></a>`remove`

Remove a deployment from an application

**Supports noop?** false

#### Parameters

##### `application`

Data type: `String[1]`

The application to operate on

##### `environment`

Data type: `String[1]`

The environment to operate on

##### `deployment_name`

Data type: `String[1]`

The name of the deployment to remove

